==> musashi-core-1.0.3.tar.gz: musashi-core-1.0.3/help/ja-euc/xtbucketHelp.h <==

#include "commonHelp.h"
/*============================================================================*/
/* ޥɥإ,man,musahi GUI ̥å                           */
/*============================================================================*/
/*----------------------------------------------------------------------------*/
/* ޥɤΥȥ                                                         */
/* ޥɥإפκǽιԤɽ                                             */
/*----------------------------------------------------------------------------*/
#define HELPT "Хåʬ"

/*----------------------------------------------------------------------------*/
/* ѥ᡼                                                                 */
/* ޥɥإפ USAGE:Ȥ" XXXT"ɽ ex)-k ̾ꥹ*/
/* flagΥץϥޥɥإפOPTIONS)Ȥɽ ex)-z : ɸϤΰ*/
/*----------------------------------------------------------------------------*/
/*-k*/
#define KEYT "̾ꥹ"
#define KEYC "ХåʬԤñ̤Ȥʤ̾ꥹ"

/*-f*/
#define FLDT "ʬ䤹̾ꥹ"
#define FLDC "ǻꤷܤͤ˴Ťʬ򤪤ʤ"
#define FLDF NULL

/*-n*/
#define NUMT "ʬ"
#define NUMC "ʬ䤹ХåȤοꤹ"

/*-F*/
#define FMTT "Ϸ"
#define FMTC "ХåȤ̾Ϸ"
#define FMTS "Хåֹ,ϰ,Хåֹ+ϰ"

/*-c*/
#define TYPT "Хåȥ"
#define TYPC "ХåȤοϰϤηꤹ"
#define TYPS "Хå,ϰ϶Хå"

/*-r*/
#define REVT "ս"
#define REVC "ХåֹϤȤͤ礭˥Хåֹ1դäƤ"

/*-i*/
#define INFT C_INFT
#define INFC C_INFC

/*-o*/
#define OTFT C_OTFT
#define OTFC C_OTFC

/*-z*/
#define ZIPT C_ZIPT
#define ZIPC C_ZIPC

/*-t*/
#define TXTT C_TXTT
#define TXTC C_TXTC

/*-T*/
#define TMPT C_TMPT
#define TMPC C_TMPC

/*----------------------------------------------------------------------------*/
/*                                                                        */
/* ޥɥإפSUMMARY:Ȥɽ                                     */
/* HTMLإפmanˤϡHELPDξ˷礹ɽ                   */
/*----------------------------------------------------------------------------*/
#define HELPS "̾ꥹȤǻꤷܤñ̤ˤơ-fΤǻꤷ͹ܤ򡢤Ǥˤʤ褦ʥХåȤʬ䤹롣"

/*----------------------------------------------------------------------------*/
/*                                                                          */
/*----------------------------------------------------------------------------*/
#define HELPE "\
xtbucket -f , -n 5 -i dat.xt -o rsl.xt\n\
xtbucket -f , -n 5 -F 1 -i dat.xt -o rsl.xt\n\
xtbucket -k ܵ -f , -n 5 -i dat.xt -o rsl.xt\n\
"

/*----------------------------------------------------------------------------*/
/* ȥޥ(ɬޤǶڤꡢѤʤ)                           */
/*----------------------------------------------------------------------------*/
#define HELPR "xtagg,xtstatistics,xtshare"

/*----------------------------------------------------------------------------*/
/* ԤˤĤ                                                               */
/* ޥɥإפˤɽʤ                                             */
/*----------------------------------------------------------------------------*/
#define HELPA C_HELPA

/*----------------------------------------------------------------------------*/
/* Хݡ                                                               */
/* ϿХޥɥإפBUG REPORT:ɽ롣                  */
/* Ͽʤ(#define HELPB "")ɽʤ                           */
/*----------------------------------------------------------------------------*/
#define HELPB C_HELPB

/*----------------------------------------------------------------------------*/
/* ۡڡ                                                               */
/* ϿХޥɥإפINFORMATION:ɽ롣                 */
/* Ͽʤ(#define HELPH "")ɽʤ                           */
/*----------------------------------------------------------------------------*/
#define HELPH C_HELPH

==> musashi-core-1.0.4-pre6.tar.gz: musashi-core-1.0.4-pre6/help/ja-euc/xtbucketHelp.h <==

#include "commonHelp.h"
/*============================================================================*/
/* ޥɥإ,man,musahi GUI ̥å                           */
/*============================================================================*/
/*----------------------------------------------------------------------------*/
/* ޥɤΥȥ                                                         */
/* ޥɥإפκǽιԤɽ                                             */
/*----------------------------------------------------------------------------*/
#define HELPT "Хåʬ"

/*----------------------------------------------------------------------------*/
/* ѥ᡼                                                                 */
/* ޥɥإפ USAGE:Ȥ" XXXT"ɽ ex)-k ̾ꥹ*/
/* flagΥץϥޥɥإפOPTIONS)Ȥɽ ex)-z : ɸϤΰ*/
/*----------------------------------------------------------------------------*/
/*-k*/
#define KEYT "̾ꥹ"
#define KEYC "ХåʬԤñ̤Ȥʤ̾ꥹ"

/*-f*/
#define FLDT "ʬ䤹̾ꥹ"
#define FLDC "ǻꤷܤͤ˴Ťʬ򤪤ʤ"
#define FLDF NULL

/*-n*/
#define NUMT "ʬ"
#define NUMC "ʬ䤹ХåȤοꤹ"

/*-F*/
#define FMTT "Ϸ"
#define FMTC "ХåȤ̾Ϸ"
#define FMTS "Хåֹ,ϰ,Хåֹ+ϰ"

/*-c*/
#define TYPT "Хåȥ"
#define TYPC "ХåȤοϰϤηꤹ"
#define TYPS "Хå,ϰ϶Хå"

/*-r*/
#define REVT "ս"
#define REVC "ХåֹϤȤͤ礭˥Хåֹ1դäƤ"

/*-O*/
#define RNGT "ХåϰϽϥե"
#define RNGC "ƹ(-f)γƥХåȤοϰϤϤե̾"

/*-a*/
#define FNMT C_FNMT
#define FNMC C_FNMC

/*-i*/
#define INFT C_INFT
#define INFC C_INFC

/*-o*/
#define OTFT C_OTFT
#define OTFC C_OTFC

/*-z*/
#define ZIPT C_ZIPT
#define ZIPC C_ZIPC

/*-t*/
#define TXTT C_TXTT
#define TXTC C_TXTC

/*-T*/
#define TMPT C_TMPT
#define TMPC C_TMPC

/*----------------------------------------------------------------------------*/
/*                                                                        */
/* ޥɥإפSUMMARY:Ȥɽ                                     */
/* HTMLإפmanˤϡHELPDξ˷礹ɽ                   */
/*----------------------------------------------------------------------------*/
#define HELPS "̾ꥹȤǻꤷܤñ̤ˤơ-fΤǻꤷ͹ܤ򡢤Ǥˤʤ褦ʥХåȤʬ䤹롣"

/*----------------------------------------------------------------------------*/
/*                                                                          */
/*----------------------------------------------------------------------------*/
#define HELPE "\
xtbucket -f :ۥХå,:̥Хå -n 5 -i dat.xt -o rsl.xt\n\
xtbucket -f :ۥХå,:̥Хå -n 5 -F 1 -i dat.xt -o rsl.xt\n\
xtbucket -k ܵ -f :ۥХå,:̥Хå -n 5 -i dat.xt -o rsl.xt\n\
"

/*----------------------------------------------------------------------------*/
/* ȥޥ(ɬޤǶڤꡢѤʤ)                           */
/*----------------------------------------------------------------------------*/
#define HELPR "xtagg,xtstatistics,xtshare"

/*----------------------------------------------------------------------------*/
/* ԤˤĤ                                                               */
/* ޥɥإפˤɽʤ                                             */
/*----------------------------------------------------------------------------*/
#define HELPA C_HELPA

/*----------------------------------------------------------------------------*/
/* Хݡ                                                               */
/* ϿХޥɥإפBUG REPORT:ɽ롣                  */
/* Ͽʤ(#define HELPB "")ɽʤ                           */
/*----------------------------------------------------------------------------*/
#define HELPB C_HELPB

/*----------------------------------------------------------------------------*/
/* ۡڡ                                                               */
/* ϿХޥɥإפINFORMATION:ɽ롣                 */
/* Ͽʤ(#define HELPH "")ɽʤ                           */
/*----------------------------------------------------------------------------*/
#define HELPH C_HELPH
